HTAnalysisManager class

Constructors

HTAnalysisManager(HTSourceManager<HTSource, HTResourceContext<HTSource>> sourceContextManager, {HTErrorHandlerCallback? errorHandler})

Properties

errorHandler → HTErrorHandlerCallback?
final
hashCode → int
The hash code for this object.
no setterinherited
pathsToAnalyze → Iterable<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceContextManager → HTSourceManager<HTSource, HTResourceContext<HTSource>>
The underlying context manager for analyzer to access to source.
final

Methods

analyze(String fullName) → HTSourceAnalysisResult
getParseResult(String fullName) → ASTSource?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited