HTModuleAnalysisResult class

Constructors

HTModuleAnalysisResult({required Map<String, HTSourceAnalysisResult> sourceAnalysisResults, required List<HTAnalysisError> errors, required ASTCompilation compilation})

Properties

compilation → ASTCompilation
final
errors → List<HTAnalysisError>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceAnalysisResults → Map<String, HTSourceAnalysisResult>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited