AnalyzerConfig class

Implementers

Constructors

AnalyzerConfig({bool computeConstantExpression = false, bool doStaticAnalysis = false, bool allowVariableShadowing = true, bool allowImplicitVariableDeclaration = false, bool allowImplicitNullToZeroConversion = false, bool allowImplicitEmptyValueToFalseConversion = false, bool printPerformanceStatistics = false})

Properties

allowImplicitEmptyValueToFalseConversion ↔ bool
getter/setter pair
allowImplicitNullToZeroConversion ↔ bool
getter/setter pair
allowImplicitVariableDeclaration ↔ bool
getter/setter pair
allowVariableShadowing ↔ bool
getter/setter pair
computeConstantExpression ↔ bool
getter/setter pair
doStaticAnalysis ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
printPerformanceStatistics ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited