ASTSource class

Parse result of a single file

Inheritance

Constructors

ASTSource({required List<ASTNode> nodes, List<ImportExportDecl> imports = const [], List<HTError> errors = const [], required HTSource? source, int line = 0, int column = 0, int offset = 0, int length = 0})

Properties

column → int
finalinherited
documentation → String
no setterinherited
end → int
no setterinherited
errors → List<HTError>
final
fullName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
imports → List<ImportExportDecl>
final
isAwait → bool
finalinherited
isBlock → bool
Wether this is a struct/code block expression.
finalinherited
isConstValue → bool
Wether this value is constantant value, i.e. its value is computed before compile into bytecode.
no setterinherited
isExpression → bool
no setterinherited
isResolved ↔ bool
This value is false untill assigned by analyzer
getter/setter pair
isStatement → bool
finalinherited
length → int
finalinherited
line → int
finalinherited
lineInfo → LineInfo
no setter
nodes → List<ASTNode>
final
offset → int
finalinherited
precedings ↔ List<ASTAnnotation>
getter/setter pairinherited
resourceType → HTResourceType
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
finalinherited
succeedings ↔ List<ASTAnnotation>
getter/setter pairinherited
trailing ↔ ASTAnnotation?
getter/setter pairinherited
trailingAfter ↔ ASTAnnotation?
getter/setter pairinherited
type → String
finalinherited
value ↔ dynamic
If this is a constant expressions, the constant interpreter will compute the value and assign to this property, otherwise, this peoperty is null.
getter/setter pairinherited

Methods

accept(AbstractASTVisitor visitor) → dynamic
Visit this node
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subAccept(AbstractASTVisitor visitor) → void
Visit all the sub nodes of this, doing nothing by default.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited