ClassDecl class

Inheritance

Constructors

ClassDecl(IdentifierExpr id, BlockStmt definition, {String? classId, List<GenericTypeParameterExpr> genericTypeParameters = const [], TypeExpr? superType, List<NominalTypeExpr> implementsTypes = const [], List<NominalTypeExpr> withTypes = const [], bool isExternal = false, bool isAbstract = false, bool isPrivate = false, bool isTopLevel = false, bool hasUserDefinedConstructor = false, bool lateResolve = true, bool hasEndOfStmtMark = false, HTSource? source, int line = 0, int column = 0, int offset = 0, int length = 0})

Properties

classId String?
final
column int
finalinherited
definition BlockStmt
final
documentation String
no setterinherited
end int
no setterinherited
genericTypeParameters List<GenericTypeParameterExpr>
final
hasEndOfStmtMark bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasUserDefinedConstructor bool
final
id IdentifierExpr
final
implementsTypes List<NominalTypeExpr>
final
isAbstract bool
final
isAwait bool
finalinherited
isBlock bool
Wether this is a struct/code block expression.
finalinherited
isConstValue bool
Wether this value is constantant value, i.e. its value is computed before compile into bytecode.
no setterinherited
isExpression bool
no setterinherited
isExternal bool
final
isMember bool
no setter
isNested bool
no setter
isPrivate bool
final
isStatement bool
finalinherited
isTopLevel bool
final
lateResolve bool
final
length int
finalinherited
line int
finalinherited
offset int
finalinherited
precedings List<ASTAnnotation>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source HTSource?
finalinherited
succeedings List<ASTAnnotation>
getter/setter pairinherited
superType TypeExpr?
final
trailing ASTAnnotation?
getter/setter pairinherited
trailingAfter ASTAnnotation?
getter/setter pairinherited
type String
finalinherited
value ↔ dynamic
If this is a constant expressions, the constant interpreter will compute the value and assign to this property, otherwise, this peoperty is null.
getter/setter pairinherited
withTypes List<NominalTypeExpr>
final

Methods

accept(AbstractASTVisitor visitor) → dynamic
Visit this node
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subAccept(AbstractASTVisitor visitor) → void
Visit all the sub nodes of this, doing nothing by default.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited