FuncDecl class

Inheritance

Constructors

FuncDecl(String internalName, {IdentifierExpr? id, String? classId, String? explicityNamespaceId, List<GenericTypeParameterExpr> genericTypeParameters = const [], String? externalTypeId, RedirectingConstructorCallExpr? redirectingConstructorCall, List<ParamDecl> paramDecls = const [], bool hasParamDecls = true, TypeExpr? returnType, int minArity = 0, int maxArity = 0, bool isExpressionBody = false, ASTNode? definition, bool isAsync = false, bool isExternal = false, bool isStatic = false, bool isConst = false, bool isVariadic = false, bool isPrivate = false, bool isTopLevel = false, bool isField = false, FunctionCategory category = FunctionCategory.normal, bool isStatement = true, bool hasEndOfStmtMark = false, HTSource? source, int line = 0, int column = 0, int offset = 0, int length = 0})

Properties

category FunctionCategory
final
classId String?
final
column int
finalinherited
definition ASTNode?
final
documentation String
no setterinherited
end int
no setterinherited
explicityNamespaceId String?
final
externalTypeId String?
final
genericTypeParameters List<GenericTypeParameterExpr>
final
hasEndOfStmtMark bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasParamDecls bool
final
id IdentifierExpr?
final
internalName String
final
isAbstract bool
no setter
isAsync bool
final
isAwait bool
finalinherited
isBlock bool
Wether this is a struct/code block expression.
finalinherited
isConst bool
final
isConstValue bool
Wether this value is constantant value, i.e. its value is computed before compile into bytecode.
no setterinherited
isExpression bool
no setterinherited
isExpressionBody bool
final
isExternal bool
final
isField bool
final
isPrivate bool
final
isStatement bool
finalinherited
isStatic bool
final
isTopLevel bool
final
isVariadic bool
final
length int
finalinherited
line int
finalinherited
maxArity int
final
minArity int
final
offset int
finalinherited
paramDecls List<ParamDecl>
final
precedings List<ASTAnnotation>
getter/setter pairinherited
redirectingConstructorCall RedirectingConstructorCallExpr?
final
returnType TypeExpr?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source HTSource?
finalinherited
succeedings List<ASTAnnotation>
getter/setter pairinherited
trailing ASTAnnotation?
getter/setter pairinherited
trailingAfter ASTAnnotation?
getter/setter pairinherited
type String
finalinherited
value ↔ dynamic
If this is a constant expressions, the constant interpreter will compute the value and assign to this property, otherwise, this peoperty is null.
getter/setter pairinherited

Methods

accept(AbstractASTVisitor visitor) → dynamic
Visit this node
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subAccept(AbstractASTVisitor visitor) → void
Visit all the sub nodes of this, doing nothing by default.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited