instanceMemberSet method
dynamic
instanceMemberSet(})
override
Assign a value to a instance member of the Dart class by the id, in the form of
object.key = value
Implementation
@override
dynamic instanceMemberSet(dynamic instance, String id, dynamic value,
{bool ignoreUndefined = false}) {
switch (id) {
default:
instance[id] = value;
}
}