HTNumberClassBinding class
Methods
-
contains(String id)
→ bool
-
inherited
-
define(String id, dynamic value, {bool override = false})
→ void
-
inherited
-
instanceMemberGet(dynamic instance, String id, {bool ignoreUndefined = false})
→ dynamic
-
Default HTExternalClass constructor.
Fetch a instance member of the Dart class by the
id, in the form of
override
-
instanceMemberSet(dynamic instance, String id, dynamic value, {bool ignoreUndefined = false})
→ void
-
Assign a value to a instance member of the Dart class by the
id, in the form of
inherited
-
instanceSubGet(dynamic instance, dynamic key)
→ dynamic
-
Fetch a instance member of the Dart class by the id, in the form of
inherited
-
instanceSubSet(dynamic instance, dynamic key, dynamic value)
→ void
-
Assign a value to a instance member of the Dart class by the id, in the form of
inherited
-
memberGet(String id, {String? from, bool isRecursive = false, bool ignoreUndefined = false})
→ dynamic
-
Fetch a member by the
id, in the form of
override
-
memberSet(String id, dynamic value, {String? from, bool defineIfAbsent = false})
→ void
-
Assign a value to a member by the
id, in the form of
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
subGet(dynamic id, {String? from})
→ dynamic
-
Fetch a member by the
id, in the form of
inherited
-
subSet(dynamic id, dynamic value, {String? from})
→ void
-
Assign a value to a member by the
id, in the form of
inherited
-
toString()
→ String
-
A string representation of this object.
inherited