getConstString method
fetch a contant value defined within any namespace of this module.
Implementation
String getConstString() {
final index = readUint16();
return getGlobalConstant(String, index);
}
fetch a contant value defined within any namespace of this module.
String getConstString() {
final index = readUint16();
return getGlobalConstant(String, index);
}