jsonSources property

Map<String, HTJsonSource> jsonSources
final

An interpreted non-source, such as JSON, is exist as a value in bytecode module. This is empty until interpreter insert the evaled values.

Implementation

final Map<String, HTJsonSource> jsonSources = {};