namespaces property
An interpreted source is exist as a namespace in bytecode module. This is empty until interpreter insert the evaled values.
Implementation
final Map<String, HTNamespace> namespaces = {};
An interpreted source is exist as a namespace in bytecode module. This is empty until interpreter insert the evaled values.
final Map<String, HTNamespace> namespaces = {};