version property
Version?
version
getter/setter pair
The version of this module, will be read from the bytes later.
Implementation
Version? version;
The version of this module, will be read from the bytes later.
Version? version;