BytecodeReader mixin
An utility class to read bytes and return the actual value.
- Mixin applications
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → int - Fetch a single byte at the current instruction pointer
-
readBool(
) → bool - Fetch a bool value from the bytes list
-
readFloat64(
) → double - Fetch a float64 from the bytes list
-
readInt16(
) → int - Fetch a int64 from the bytes list
-
readInt64(
) → int - Fetch a int32 from the bytes list Fetch a int64 from the bytes list Fetch a float64 from the bytes list Fetch a int64 from the bytes list Fetch a int64 from the bytes list
-
readUint16(
) → int - Fetch a uint16 from the bytes list
-
readUint32(
) → int - Fetch a uint32 from the bytes list
-
readUint8(
) → int - Fetch a uint8 from the bytes list
-
readUtf8String(
) → String - Fetch a utf8 string from the bytes list
-
skip(
int distance) → void -
Skip forward
distanceof bytes -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited