read method
Fetch a single byte at the current instruction pointer
Implementation
int read() {
assert(ip < bytes.length, 'Bytecode IP $ip out of bounds (length: ${bytes.length})');
return bytes[ip++];
}
Fetch a single byte at the current instruction pointer
int read() {
assert(ip < bytes.length, 'Bytecode IP $ip out of bounds (length: ${bytes.length})');
return bytes[ip++];
}