bytecode/compiler library

Classes

CompilerConfig
Collection of config of a compiler.
HTCompiler
Compiles source code into bytecode. Normally we won't use this class directly. Rather, we would use the interpreter class or command line tools to compile, they would use analyzer to try to find errors and compute constant values before actual compilation.