CompilerConfig class

Collection of config of a compiler.

Implementers

Constructors

CompilerConfig({bool removeLineInfo = false, bool removeAssertion = false, bool removeDocumentation = false, bool printPerformanceStatistics = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
printPerformanceStatistics ↔ bool
getter/setter pair
removeAssertion ↔ bool
getter/setter pair
removeDocumentation ↔ bool
getter/setter pair
removeLineInfo ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited