GotoInfo mixin

Execution jump point, this is a reletive jump from the current ip of the bytecode module. For absolute jumpo point, will use HTOpCode.anchor and HTOpCode.goto.

Mixin applications

Properties

column ↔ int?
latefinal
file ↔ String
latefinal
hashCode → int
The hash code for this object.
no setterinherited
ip ↔ int?
latefinal
line ↔ int?
latefinal
module ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited