HTExtensionTargetKindCode class abstract

Following OpCode.extensionDecl, tells the extension target kind, mirrors the order of ExtensionTargetKind in ast.dart.

Constructors

HTExtensionTargetKindCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

classType → const int
namespace → const int
structType → const int