OpCode class abstract

Operation code used by compiler.

Constructors

OpCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

add → const int
anchor → const int
assertion → const int
assign → const int
awaitedValue → const int
bitwiseAnd → const int
bitwiseNot → const int
bitwiseOr → const int
bitwiseXor → const int
breakLoop → const int
call → const int
classDecl → const int
classDeclEnd → const int
clearAnchor → const int
codeBlock → const int
constDecl → const int
constFloatTable → const int
constIntTable → const int
constStringTable → const int
continueLoop → const int
createStackFrame → const int
decltypeOf → const int
delete → const int
destructuringDecl → const int
devide → const int
doStmt → const int
endOfCodeBlock → const int
endOfExec → const int
endOfFile → const int
endOfFunc → const int
endOfModule → const int
endOfStmt → const int
equal → const int
extensionDecl → const int
extensionDeclEnd → const int
externalEnumDecl → const int
file → const int
funcDecl → const int
goto → const int
greater → const int
greaterOrEqual → const int
ifNull → const int
ifStmt → const int
importExportDecl → const int
isIn → const int
isNotIn → const int
leftShift → const int
lesser → const int
lesserOrEqual → const int
lineInfo → const int
local → const int
logicalAnd → const int
logicalNot → const int
logicalOr → const int
loopPoint → const int
makeList → const int
makeString → const int
makeStruct → const int
makeTuple → const int
matchCase → const int
memberGet → const int
memberSet → const int
modulo → const int
multiply → const int
namespaceDecl → const int
namespaceDeclEnd → const int
negative → const int
notEqual → const int
pop → const int
retractStackFrame → const int
rightShift → const int
skip → const int
structDecl → const int
subGet → const int
subSet → const int
subtract → const int
switchStmt → const int
throws → const int
truncatingDevide → const int
truthyValue → const int
typeAliasDecl → const int
typeAs → const int
typeIs → const int
typeIsNot → const int
typeValueOf → const int
unsignedRightShift → const int
varDecl → const int
whileStmt → const int