InternalIdentifier class base

Constructors

InternalIdentifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

anonymousBlock → const String
anonymousClass → const String
anonymousFunction → const String
anonymousScript → const String
anonymousStruct → const String
assertStatement → const String
assignExpression → const String
binaryExpression → const String
blockStatement → const String
breakStatement → const String
call → const String
callExpression → const String
classDeclaration → const String
commaExpression → const String
comment → const String
compilation → const String
constantDeclaration → const String
continueStatement → const String
defaultConstructor → const String
deleteMemberStatement → const String
deleteStatement → const String
deleteSubMemberStatement → const String
destructuringDeclaration → const String
doStatement → const String
empty → const String
emptyLine → const String
enumDeclaration → const String
exportStatement → const String
expression → const String
expressionStatement → const String
extensionDeclaration → const String
fieldTypeExpression → const String
filename → const String
forExpression → const String
forExpressionInit → const String
forRangeExpression → const String
functionDeclaration → const String
functionTypeExpression → const String
genericTypeParamExpression → const String
getter → const String
global → const String
groupExpression → const String
identifier → const String
identifierExpression → const String
ifExpression → const String
importStatement → const String
inOfExpression → const String
instance → const String
instanceOf → const String
intrinsicTypeExpression → const String
keyword → const String
lineBreak → const String
literalBoolean → const String
literalFloat → const String
literalInteger → const String
literalList → const String
literalNull → const String
literalString → const String
literalStruct → const String
literalStructField → const String
memberGetExpression → const String
module → const String
name → const String
namedConstructorPrefix → const String
namespace → const String
namespaceDeclaration → const String
nominalTypeExpression → const String
parameterDeclaration → const String
paramTypeExpression → const String
primaryExpression → const String
prototype → const String
punctuation → const String
redirectingConstructor → const String
returnStatement → const String
setter → const String
source → const String
spreadExpression → const String
statement → const String
stringInterpolation → const String
structDeclaration → const String
structuralTypeExpression → const String
subGetExpression → const String
subGetter → const String
subSetter → const String
switchStatement → const String
ternaryExpression → const String
throwStatement → const String
typeAliasDeclaration → const String
unaryPostfixExpression → const String
unaryPrefixExpression → const String
variableDeclaration → const String
whileStatement → const String