HTClassDeclaration class

Inheritance
Implemented types
Implementers

Constructors

HTClassDeclaration({String? id, String? classId, HTDeclarationNamespace? closure, HTSource? source, String? documentation, List<HTGenericTypeParameter> genericTypeParameters = const [], HTType? superType, Iterable<HTType> implementsTypes = const [], Iterable<HTType> withTypes = const [], bool isPrivate = false, bool isExternal = false, bool isTopLevel = false, bool isAbstract = false, bool isEnum = false})

Properties

classId → String?
Wether this declaration is a class member.
finalinherited
closure → HTDeclarationNamespace?
finalinherited
declType → HTType?
no setterinherited
displayName → String
no setterinherited
documentation → String?
finalinherited
genericTypeParameters → List<HTGenericTypeParameter>
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
idRange → SourceRange
finalinherited
implementsTypes → Iterable<HTType>
Implemented classes of this class. Implements only inherits methods declaration, and the child must re-define all implements methods, and the re-definition must be of the same function signature.
final
isAbstract → bool
final
isConst → bool
Wether this declaration is a const value.
finalinherited
isEnum → bool
final
isExternal → bool
Wether this declaration is from outside of the script.
finalinherited
isField → bool
Wether this declaration is a member of a class or struct.
finalinherited
isMutable → bool
Wether this declaration's value can be assigned to another value.
finalinherited
isNested → bool
no setter
isPrivate → bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic → bool
Wether this declaration is static in a class.
finalinherited
isTopLevel → bool
Wether this declaration is defined on top level of a source.
finalinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
finalinherited
sourceRange → SourceRange
finalinherited
superType → HTType?
no setter
value ↔ dynamic
getter/setter pairinherited
withTypes → Iterable<HTType>
Mixined class of this class. Those mixined class can not have any constructors.
final

Methods

clone() → HTClassDeclaration
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited