HTDeclaration class abstract

Declaration is a semantic entity in the program that represents things that are declared with a name and hence can be referenced elsewhere in the code. Declaration is not necessarily exists in actual namespaces, some declaration are generated purely for analysis purpose.

Implementers

Constructors

HTDeclaration({String? id, String? classId, HTDeclarationNamespace? closure, HTSource? source, SourceRange idRange = SourceRange.empty, SourceRange sourceRange = SourceRange.empty, bool isPrivate = false, bool isExternal = false, bool isStatic = false, bool isConst = false, bool isMutable = false, bool isTopLevel = false, bool isField = false, String? documentation})
const

Properties

classId → String?
Wether this declaration is a class member.
final
closure → HTDeclarationNamespace?
final
declType → HTType?
no setter
displayName → String
no setter
documentation → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
idRange → SourceRange
final
isConst → bool
Wether this declaration is a const value.
final
isExternal → bool
Wether this declaration is from outside of the script.
final
isField → bool
Wether this declaration is a member of a class or struct.
final
isMutable → bool
Wether this declaration's value can be assigned to another value.
final
isPrivate → bool
Wether this declaration is only accessible from the same namespace.
no setter
isStatic → bool
Wether this declaration is static in a class.
final
isTopLevel → bool
Wether this declaration is defined on top level of a source.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
final
sourceRange → SourceRange
final
value ↔ dynamic
getter/setter pair

Methods

clone() → dynamic
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited