HTAbstractParameter class abstract

A interface shared by parameter declaration and parameter this is to fix mulitple inheritance issue.

Implemented types
Implementers

Constructors

HTAbstractParameter()

Properties

classId → String?
Wether this declaration is a class member.
finalinherited
closure → HTDeclarationNamespace?
finalinherited
declType → HTType?
no setteroverride
displayName → String
no setterinherited
documentation → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
idRange → SourceRange
finalinherited
isConst → bool
Wether this declaration is a const value.
finalinherited
isExternal → bool
Wether this declaration is from outside of the script.
finalinherited
isField → bool
Wether this declaration is a member of a class or struct.
finalinherited
isInitialization → bool
no setter
isMutable → bool
Wether this declaration's value can be assigned to another value.
finalinherited
isNamed → bool
no setter
isOptional → bool
no setter
isPrivate → bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic → bool
Wether this declaration is static in a class.
finalinherited
isTopLevel → bool
Wether this declaration is defined on top level of a source.
finalinherited
isVariadic → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
finalinherited
sourceRange → SourceRange
finalinherited
value ↔ dynamic
getter/setter pairinherited

Methods

clone() → HTAbstractParameter
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
initialize() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited