HTFunctionDeclaration class

Inheritance
Implemented types
Implementers

Constructors

HTFunctionDeclaration({required String internalName, String? id, String? classId, String? explicityNamespaceId, HTDeclarationNamespace? closure, HTSource? source, String? documentation, bool isPrivate = false, bool isExternal = false, bool isStatic = false, bool isConst = false, bool isTopLevel = false, bool isField = false, FunctionCategory category = FunctionCategory.normal, String? externalTypeId, List<HTGenericTypeParameter> genericTypeParameters = const [], bool hasParamDecls = true, Map<String, HTAbstractParameter> paramDecls = const {}, HTFunctionType? declType, bool isAsync = false, bool isAbstract = false, bool isVariadic = false, int minArity = 0, int maxArity = 0})

Properties

category → FunctionCategory
final
classId → String?
Wether this declaration is a class member.
finalinherited
closure → HTDeclarationNamespace?
finalinherited
declType → HTFunctionType
no setteroverride
displayName → String
no setterinherited
documentation → String?
finalinherited
explicityNamespaceId → String?
Wether this declaration is within a explicity namespace declaration.
final
externalTypeId → String?
final
genericTypeParameters → List<HTGenericTypeParameter>
final
hashCode → int
The hash code for this object.
no setterinherited
hasParamDecls → bool
Wether to check params when called A function like:
final
id → String?
finalinherited
idRange → SourceRange
finalinherited
internalName → String
final
isAbstract → bool
final
isAsync → bool
final
isConst → bool
Wether this declaration is a const value.
finalinherited
isExternal → bool
Wether this declaration is from outside of the script.
finalinherited
isField → bool
Wether this declaration is a member of a class or struct.
finalinherited
isMutable → bool
Wether this declaration's value can be assigned to another value.
finalinherited
isPrivate → bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic → bool
Wether this declaration is static in a class.
finalinherited
isTopLevel → bool
Wether this declaration is defined on top level of a source.
finalinherited
isVariadic → bool
final
maxArity → int
final
minArity → int
final
paramDecls → Map<String, HTAbstractParameter>
Holds declarations of all parameters.
final
returnType → HTType?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
finalinherited
sourceRange → SourceRange
finalinherited
value ↔ dynamic
getter/setter pairinherited

Methods

clone() → HTFunctionDeclaration
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({bool resolveType = true}) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited