hasParamDecls property
Wether to check params when called A function like:
function { return 42 }
will accept any params, while a function:
function () { return 42 }
will accept 0 params
Implementation
final bool hasParamDecls;
Wether to check params when called A function like:
function { return 42 }
will accept any params, while a function:
function () { return 42 }
will accept 0 params
final bool hasParamDecls;