declarations library

Classes

HasGenericTypeParameter
HTClassDeclaration
HTDeclaration
Declaration is a semantic entity in the program that represents things that are declared with a name and hence can be referenced elsewhere in the code. Declaration is not necessarily exists in actual namespaces, some declaration are generated purely for analysis purpose.
HTFunctionDeclaration
HTGenericTypeParameter
A Generic Type Parameter could be:
HTNamespace
A namespace that will return the actual value of the declaration.
HTParameterDeclaration
HTTypeAliasDeclaration
Similar to variable, but the value is a type. And can have generic type parameters.
HTVariableDeclaration