ErrorProcessor class

Process errors by filtering or changing associated MessageSeverity.

Constructors

ErrorProcessor(String name, [MessageSeverity? severity])
Create an error processor that assigns errors with this code the given severity.
const

Properties

description → String
The string that unique describes the processor.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The code name of the associated error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → MessageSeverity?
The desired severity of the processed error.
final

Methods

appliesTo(HTError error) → bool
Check if this processor applies to the given error.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getProcessor(HTAnalyzer? analyzer, HTError error) → ErrorProcessor?
Return an error processor associated in the analysisOptions for the given error, or null if none is found.