HTErrorCode enum

Inheritance
Available extensions

Values

unkownSourceType → const HTErrorCode
importListOnNonHetuSource → const HTErrorCode
exportNonHetuSource → const HTErrorCode
scriptThrows → const HTErrorCode
assertionFailed → const HTErrorCode
unexpectedToken → const HTErrorCode
unexpected → const HTErrorCode
delete → const HTErrorCode
external → const HTErrorCode
nestedClass → const HTErrorCode
constInClass → const HTErrorCode
misplacedThis → const HTErrorCode
misplacedSuper → const HTErrorCode
misplacedReturn → const HTErrorCode
misplacedContinue → const HTErrorCode
misplacedBreak → const HTErrorCode
setterArity → const HTErrorCode
unexpectedEmptyList → const HTErrorCode
extendsSelf → const HTErrorCode
missingFuncBody → const HTErrorCode
externalCtorWithReferCtor → const HTErrorCode
resourceDoesNotExist → const HTErrorCode
sourceProviderError → const HTErrorCode
notAbsoluteError → const HTErrorCode
invalidDeclTypeOfValue → const HTErrorCode
invalidLeftValue → const HTErrorCode
awaitWithoutAsync → const HTErrorCode
nullableAssign → const HTErrorCode
privateMember → const HTErrorCode
constMustInit → const HTErrorCode
awaitExpression → const HTErrorCode
getterParam → const HTErrorCode
structMemberId → const HTErrorCode
ifBlock → const HTErrorCode
asyncConstructor → const HTErrorCode
defined → const HTErrorCode
outsideThis → const HTErrorCode
notMember → const HTErrorCode
notClass → const HTErrorCode
notNamespace → const HTErrorCode
abstracted → const HTErrorCode
abstractFunction → const HTErrorCode
interfaceCtor → const HTErrorCode
unsupported → const HTErrorCode
bytecode → const HTErrorCode
version → const HTErrorCode
extern → const HTErrorCode
unknownOpCode → const HTErrorCode
notInitialized → const HTErrorCode
undefined → const HTErrorCode
undefinedExternal → const HTErrorCode
unknownTypeName → const HTErrorCode
undefinedOperator → const HTErrorCode
notNewable → const HTErrorCode
notCallable → const HTErrorCode
undefinedMember → const HTErrorCode
uninitialized → const HTErrorCode
condition → const HTErrorCode
nullObjectCall → const HTErrorCode
nullObjectGet → const HTErrorCode
nullSubSetKey → const HTErrorCode
subGetKey → const HTErrorCode
outOfRange → const HTErrorCode
assignType → const HTErrorCode
immutable → const HTErrorCode
notType → const HTErrorCode
argType → const HTErrorCode
argInit → const HTErrorCode
returnType → const HTErrorCode
stringInterpolation → const HTErrorCode
arity → const HTErrorCode
externalVar → const HTErrorCode
bytesSig → const HTErrorCode
circleInit → const HTErrorCode
namedArg → const HTErrorCode
iterable → const HTErrorCode
unkownValueType → const HTErrorCode
typeCast → const HTErrorCode
castee → const HTErrorCode
notSuper → const HTErrorCode
unresolvedNamedStruct → const HTErrorCode
binding → const HTErrorCode
notStruct → const HTErrorCode
notSpreadableObj → const HTErrorCode
constValue → const HTErrorCode
importSelf → const HTErrorCode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HTErrorCode>
A constant List of the values in this enum, in order of their declaration.