ErrorHandlerConfig class

Implementers

Constructors

ErrorHandlerConfig({bool showDartStackTrace = false, bool showHetuStackTrace = false, int stackTraceDisplayCountLimit = 5, bool processError = true, bool debugMode = false})

Properties

debugMode ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
processError ↔ bool
Wether fill in errors with detailed information, e.g. line & column info.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDartStackTrace ↔ bool
getter/setter pair
showHetuStackTrace ↔ bool
getter/setter pair
stackTraceDisplayCountLimit ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited