instanceSubSet method

void instanceSubSet(
  1. dynamic instance,
  2. dynamic key,
  3. dynamic value
)

Assign a value to a instance member of the Dart class by the id, in the form of

object[key] = value

Implementation

void instanceSubSet(dynamic instance, dynamic key, dynamic value) =>
    instance[key] = value;