FormatterConfig class

Constructors

FormatterConfig({int pageWidth = 80, bool formatStringMark = true, bool preferApostrophe = true, bool removeTrailingComma = true, bool removeSemicolon = true, String indent = ' '})
const

Properties

formatStringMark → bool
final
hashCode → int
The hash code for this object.
no setterinherited
indent → String
final
pageWidth → int
final
preferApostrophe → bool
final
removeSemicolon → bool
final
removeTrailingComma → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited