FutureExecution class
A wrapper class for the bytecode interpreter to run a certain task in a future. This is only used internally.
Constructors
- FutureExecution({required Future future, required HTContext context, required HTStackFrame stack})
Properties
- context ↔ HTContext
-
getter/setter pair
- future ↔ Future
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stack ↔ HTStackFrame
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited