bindExternalMethod method
Register a external method in scrfipt there must be a declaraction also in script for using this the function here must be a HTExternalMethod use id like '$classId::$functionId'
Implementation
void bindExternalMethod(String id, Function method, {bool override = true}) {
assert(method is HTExternalMethod);
assert(id.contains('::'));
if (externalMethods.containsKey(id) && !override) {
throw HTError.defined(id, HTErrorType.runtimeError);
}
externalMethods[id] = method;
}