bindExternalReflection method

void bindExternalReflection(
  1. HTExternalTypeReflection reflection
)

Bind an external class name to a abstract class name for interpreter getting dart class name by reflection

Implementation

void bindExternalReflection(HTExternalTypeReflection reflection) {
  externalTypeReflection.add(reflection);
}