InterpreterConfig class

Collection of config of bytecode interpreter.

Implemented types
Implementers

Constructors

InterpreterConfig({bool showDartStackTrace = false, bool showHetuStackTrace = false, int stackTraceDisplayCountLimit = 5, bool processError = true, bool debugMode = false, bool allowVariableShadowing = true, bool allowImplicitVariableDeclaration = false, bool allowImplicitNullToZeroConversion = false, bool allowImplicitEmptyValueToFalseConversion = false, bool allowInitializationExpresssionHaveValue = false, bool printPerformanceStatistics = false, bool checkTypeAnnotationAtRuntime = false, bool resolveExternalFunctionsDynamically = false})

Properties

allowImplicitEmptyValueToFalseConversion ↔ bool
getter/setter pair
allowImplicitNullToZeroConversion ↔ bool
getter/setter pair
allowImplicitVariableDeclaration ↔ bool
getter/setter pair
allowInitializationExpresssionHaveValue ↔ bool
getter/setter pair
allowVariableShadowing ↔ bool
getter/setter pair
checkTypeAnnotationAtRuntime ↔ bool
getter/setter pair
debugMode ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
printPerformanceStatistics ↔ bool
getter/setter pair
processError ↔ bool
Wether fill in errors with detailed information, e.g. line & column info.
getter/setter pairoverride
resolveExternalFunctionsDynamically ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDartStackTrace ↔ bool
getter/setter pairoverride
showHetuStackTrace ↔ bool
getter/setter pairoverride
stackTraceDisplayCountLimit ↔ int
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited