InterpreterRef mixin

Mixin for classes that want to hold a ref of a bytecode interpreter

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ HTInterpreter
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited