HTLexer class abstract
- Implementers
Properties
Methods
-
lex(
String content, {int line = 1, int column = 1, int offset = 0}) → Token -
Scan a string content and convert it into a linked list of tokens.
The last element in the list will always be a
end_of_filetoken. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited