Token class

Implementers

Constructors

Token({required String lexeme, required int line, required int column, required int offset, bool isKeyword = false, Token? previous, Token? next})

Properties

column → int
final
end → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
isKeyword → bool
final
length → int
no setter
lexeme → String
final
line → int
final
literal → dynamic
no setter
next ↔ Token?
getter/setter pair
offset → int
the start position of this token
final
previous ↔ Token?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

endOfFile → const String
end_of_file token lexeme.