HTLocale class abstract

An abstract interface for a locale that contains error messages.

Implementers

Constructors

HTLocale()

Properties

assertStatement String
no setter
assignExpression String
no setter
asyncFunction String
no setter
binaryExpression String
no setter
blockStatement String
no setter
breakStatement String
no setter
callExpression String
no setter
caseBranch String
no setter
classDeclaration String
no setter
classDefinition String
no setter
closureExpression String
no setter
column String
no setter
commaExpression String
no setter
comment String
no setter
compilation String
no setter
constantDeclaration String
no setter
constructor String
no setter
constructorCall String
no setter
continueStatement String
no setter
declarationStatement String
no setter
deleteMemberStatement String
no setter
deleteStatement String
no setter
deleteSubMemberStatement String
no setter
destructuringDeclaration String
no setter
doStatement String
no setter
elseBranch String
no setter
empty String
no setter
emptyLine String
no setter
enumDeclaration String
no setter
errorAbstracted String
no setter
errorAbstractFunction String
no setter
errorArgInit String
no setter
errorArgType String
no setter
errorArity String
no setter
errorAssertionFailed String
no setter
errorAssignType String
no setter
errorAsyncConstructor String
no setter
errorAwaitExpression String
no setter
errorAwaitWithoutAsync String
no setter
errorBinding String
no setter
errorBytecode String
no setter
errorBytesSig String
no setter
errorCallNullObject String
no setter
errorCastee String
no setter
errorCircleInit String
no setter
errorCondition String
no setter
errorConstInClass String
no setter
errorConstMustInit String
no setter
errorConstValue String
no setter
errorDefined String
no setter
errorDefinedImportSymbol String
no setter
errorDelete String
no setter
errorExportNonHetuSource String
no setter
errorExtendsSelf String
no setter
errorExternal String
no setter
errorExternalCtorWithReferCtor String
no setter
errorExternalVar String
no setter
errorGetterParam String
no setter
errorIfBlock String
no setter
errorImmutable String
no setter
errorImportListOnNonHetuSource String
no setter
errorImportSelf String
no setter
errorInvalidDeclTypeOfValue String
no setter
errorInvalidLeftValue String
no setter
errorIterable String
no setter
errorMisplacedBreak String
no setter
errorMisplacedContinue String
no setter
errorMisplacedReturn String
no setter
errorMisplacedSuper String
no setter
errorMisplacedThis String
no setter
errorMissingFuncBody String
no setter
errorNamedArg String
no setter
errorNestedClass String
no setter
errorNotAbsoluteError String
no setter
errorNotCallable String
no setter
errorNotClass String
no setter
errorNotInitialized String
no setter
errorNotMember String
no setter
errorNotNamespace String
no setter
errorNotNewable String
no setter
errorNotSpreadableObj String
no setter
errorNotStruct String
no setter
errorNotSuper String
no setter
errorNotType String
no setter
errorNullableAssign String
no setter
errorNullSubSetKey String
no setter
errorOutOfRange String
no setter
errorOutsideThis String
no setter
errorPrivateMember String
no setter
errorResourceDoesNotExist String
no setter
errorReturnType String
no setter
errorSetterArity String
no setter
errorSourceProviderError String
no setter
errorStringInterpolation String
no setter
errorStructMemberId String
no setter
errorSubGetKey String
no setter
errorType String
no setter
errorTypeCast String
no setter
errorUndefined String
no setter
errorUndefinedExternal String
no setter
errorUndefinedMember String
no setter
errorUndefinedOperator String
no setter
errorUnexpected String
no setter
errorUnexpectedEmptyList String
no setter
errorUnexpectedToken String
no setter
errorUninitialized String
no setter
errorUnknownOpCode String
no setter
errorUnknownTypeName String
no setter
errorUnkownSourceType String
no setter
errorUnkownValueType String
no setter
errorUnresolvedNamedStruct String
no setter
errorUnsupported String
no setter
errorVersion String
no setter
errorVisitMemberOfNullObject String
no setter
exportStatement String
no setter
exportSymbols String
no setter
expression String
no setter
expressionStatement String
no setter
externalStackTrace String
no setter
factory String
no setter
fieldTypeExpression String
no setter
file String
no setter
forExpression String
no setter
forExpressionInit String
no setter
forRangeExpression String
no setter
function String
no setter
functionCall String
no setter
functionDeclaration String
no setter
functionDefinition String
no setter
functionTypeExpression String
no setter
genericTypeParamExpression String
no setter
global String
no setter
groupExpression String
no setter
hashCode int
The hash code for this object.
no setterinherited
identifier String
no setter
identifierExpression String
no setter
ifExpression String
no setter
importStatement String
no setter
importSymbols String
no setter
inOfExpression String
no setter
intrinsicTypeExpression String
no setter
keyword String
no setter
libraryStatement String
no setter
line String
no setter
literalBoolean String
no setter
literalFloat String
no setter
literalFunction String
no setter
literalInteger String
no setter
literalList String
no setter
literalNull String
no setter
literalString String
no setter
literalStruct String
no setter
literalStructField String
no setter
literalTypeExpression String
no setter
memberGetExpression String
no setter
memberSetExpression String
no setter
message String
no setter
module String
no setter
namespace String
no setter
namespaceDeclaration String
no setter
nominalTypeExpression String
no setter
parameterDeclaration String
no setter
paramTypeExpression String
no setter
percentageMark String
no setter
primaryExpression String
no setter
punctuation String
no setter
rangeExpression String
no setter
redirectingConstructor String
no setter
redirectingFunctionDefinition String
no setter
returnStatement String
no setter
returnType String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptStackTrace String
no setter
source String
no setter
spreadExpression String
no setter
statement String
no setter
stringInterpolation String
no setter
structDeclaration String
no setter
structDefinition String
no setter
structuralTypeExpression String
no setter
subGetExpression String
no setter
subSetExpression String
no setter
switchStatement String
no setter
ternaryExpression String
no setter
thenBranch String
no setter
thisExpression String
no setter
throwStatement String
no setter
typeAliasDeclaration String
no setter
typeArguments String
no setter
typeExpression String
no setter
typeName String
no setter
typeParameters String
no setter
unaryPostfixExpression String
no setter
unaryPrefixExpression String
no setter
unionTypeExpression String
no setter
variableDeclaration String
no setter
whileStatement String
no setter

Methods

getErrorType(String errType) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current HTLocale
getter/setter pair