MessageSeverity class

The severity of an message.

Implemented types

Constructors

MessageSeverity(String name, int weight, String displayName)
Initialize a newly created severity with the given names.
const

Properties

displayName String
The name of the severity used when producing readable output.
final
hashCode int
The hash code for this object.
no setteroverride
name String
The name of this error code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weight int
The weight value of the error code.
final

Methods

compareTo(MessageSeverity other) int
Compares this object to another object.
override
max(MessageSeverity severity) MessageSeverity
Return the severity constant that represents the greatest severity.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(MessageSeverity other) bool
operator <=(MessageSeverity other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(MessageSeverity other) bool
operator >=(MessageSeverity other) bool

Static Methods

of(String name) MessageSeverity

Constants

debug → const MessageSeverity
The severity representing an debug message.
error → const MessageSeverity
The severity representing an error.
info → const MessageSeverity
The severity representing an informational level analysis issue.
none → const MessageSeverity
The severity representing a non-error. This is never used for any error code, but is useful for clients.
values → const List<MessageSeverity>
warning → const MessageSeverity
The severity representing a warning.