parser library

Classes

AbstractASTVisitor<T>
An object that can be used to visit an AST structure.
AssertStmt
AssignExpr
ASTAnnotation
Comments or empty lines. Which has no meaning when interpreting, but they have meanings in formatting, so we keeps them as a special ASTNode.
ASTComment
ASTCompilation
A bundle of all imported sources
ASTEmpty
ASTEmptyLine
ASTLiteralBoolean
ASTLiteralFloat
ASTLiteralInteger
ASTLiteralNull
ASTLiteralString
ASTNode
An abstract node of an abstract syntax tree.
ASTSource
Parse result of a single file
ASTStringInterpolation
BinaryExpr
BlockStmt
BreakStmt
CallExpr
ClassDecl
ContinueStmt
DeleteMemberStmt
DeleteStmt
DeleteSubStmt
DestructuringDecl
DoStmt
EnumDecl
ExprStmt
ExtensionDecl
FieldTypeExpr
ForExpr
ForRangeExpr
FuncDecl
FuncTypeExpr
GenericTypeParameterExpr
GroupExpr
HTLexer
HTLexerHetu
HTLexicon
Lexicon used by Hetu
HTLexiconHetu
Default lexicon implementation used by Hetu. Most of the lexicon are borrowed from Javascript.
HTParser
A general parser, with abstract method to parse a token list or string content.
HTParserHetu
Default parser implementation used by Hetu.
IdentifierExpr
IfExpr
ImportExportDecl
InOfExpr
IntrinsicTypeExpr
ListExpr
MemberExpr
NamespaceDecl
NominalTypeExpr
ParallelExpr
ParamDecl
ParamTypeExpr
ParserConfig
RecursiveASTVisitor<T>
An AST visitor that will recursively visit all of the sub nodes in an AST structure. For example, using an instance of this class to visit a Block will also cause all of the statements in the node to be visited.
RedirectingConstructorCallExpr
ReturnStmt
SpreadExpr
Statement
StructDecl
StructObjExpr
StructObjField
StructuralTypeExpr
SubExpr
SwitchStmt
TernaryExpr
ThrowStmt
Token
TokenBooleanLiteral
TokenComment
TokenEmptyLine
TokenFloatLiteral
TokenIdentifier
TokenIntegerLiteral
TokenStringInterpolation
TokenStringLiteral
TypeAliasDecl
TypeExpr
UnaryPostfixExpr
e++, e--
UnaryPrefixExpr
-e, !e,++e, --e
VarDecl
WhileStmt

Enums

ExtensionTargetKind
ParseStyle
Determines how to parse a piece of code

Mixins

TokenReader
Mixin for handling a token list.