Console class

Constructors

Console({required HTLexicon lexicon, HTLogger logger = const HTConsoleLogger()})

Properties

hashCode → int
The hash code for this object.
no setterinherited
lexicon ↔ HTLexicon
getter/setter pair
logger ↔ HTLogger
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(dynamic messages) → void
error(dynamic messages) → void
info(dynamic messages) → void
log(dynamic messages, {MessageSeverity severity = MessageSeverity.none}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
time(String? id) → void
timeEnd(String? id) → int?
timeLog(String? id, {bool endTimer = false}) → int?
toString() → String
A string representation of this object.
inherited
warning(dynamic messages) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited