resource/resource_context library

Classes

HTFilterConfig
A filter used by source context for reading files with certain extensions and/or within certain folders.
HTResourceContext<T>
HTResourceContext are a set of resources, each has a unique path. It could be a physical folder, a virtual collection in memory, an URL, or a remote database... any thing that provide create, read, update, delete services could be a resource context.