HTJsonSource class

A value, however it can be imported like a source. Typically a json file, which is a HTStruct value in Hetu Script.

Constructors

HTJsonSource({required String fullName, required String module, required dynamic value})
const

Properties

fullName String
final
hashCode int
The hash code for this object.
no setterinherited
module String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited