HTParameterType class

Constructors

HTParameterType({String? id, HTType? declType, required bool isOptional, required bool isVariadic})
const

Properties

declType → HTType?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
Wether this is a named parameter.
final
isNamed → bool
no setter
isOptional → bool
Wether this is an optional parameter.
final
isVariadic → bool
Wether this is a variadic parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited