HTNominalType class

A type checks ids and its super types.

Unresolved nominal type are type name generated in parsing process. Which could lead to a type alias or a type within a namespace or a simple nominal type. It would be syntactically correct, but not neccessarily actually exist. Thus it needs to be resolved to become a concrete type.

Inheritance

Constructors

HTNominalType({String? id, HTClassDeclaration? klass, List<HTType> typeArgs = const [], bool isNullable = false, List<String> namespacesWithin = const []})

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String?
finalinherited
isBottom → bool
This type is assignable to all other types.
no setterinherited
isNullable → bool
final
isResolved → bool
no setteroverride
isTop → bool
Every type is assignable to a top type,
no setterinherited
klass → HTClassDeclaration?
final
namespacesWithin → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArgs → List<HTType>
final

Methods

isA(HTType? other) → bool
Check wether value of this HTType can be assigned to other HTType.
override
isNotA(HTType? other) → bool
Wether object of this HTType cannot be assigned to other HTType
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(HTDeclarationNamespace namespace) → HTType
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override