type/type
library
Classes
HTIntrinsicType
Types that predefined by the interpreter.
HTType
Type is basically a set of things.
It is used to check errors in code.
HTTypeAny
A type is both top and bottom, only used on declaration for analysis.
HTTypeFunction
A function type. It's the same to type () -> any.
HTTypeNamespace
HTTypeNever
A bottom type. A function whose return type is never cannot return.
For example by throwing an error or looping forever.
HTTypeNull
A zero type. It's the type of runtime null value.
You cannot get this type via expression or declaration.
HTTypeObject
HTTypeType
HTTypeUnknown
A top type, basically a type-safe version of the type any.
HTTypeVoid
A empty type. A function whose return type is empty.
It may contain return statement, but cannot return any value.
And you cannot use the function call result in any operation.