HTIntrinsicType class

Types that predefined by the interpreter.

Inheritance
Implementers

Constructors

HTIntrinsicType(String? id, {required bool isTop, required bool isBottom})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
isBottom → bool
This type is assignable to all other types.
final
isResolved → bool
no setterinherited
isTop → bool
Every type is assignable to a top type,
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isA(HTType? other) → bool
Check wether value of this HTType can be assigned to other HTType.
override
isNotA(HTType? other) → bool
Wether object of this HTType cannot be assigned to other HTType
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(HTDeclarationNamespace namespace) → HTType
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited