HTTypeUnknown class

A top type, basically a type-safe version of the type any.

Every type is assignable to type unknown (the meaning of top).

Type unknown cannot assign to other types except any & unknown.

You cannot do anything with it, unless you do an explicit type assertion.

Inheritance

Constructors

HTTypeUnknown(String? id)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
isBottom bool
This type is assignable to all other types.
finalinherited
isResolved bool
no setterinherited
isTop bool
Every type is assignable to a top type,
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isA(HTType? other) bool
Check wether value of this HTType can be assigned to other HTType.
inherited
isNotA(HTType? other) bool
Wether object of this HTType cannot be assigned to other HTType
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(HTDeclarationNamespace namespace) HTType
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited