HTConstantValue class

Inheritance

Constructors

HTConstantValue({required String id, required Type type, required int index, String? classId, String? documentation, bool isTopLevel = false, required HTGlobalConstantTable globalConstantTable, bool isPrivate = false})

Properties

classId → String?
Wether this declaration is a class member.
finalinherited
closure → HTDeclarationNamespace?
finalinherited
declType → HTType?
no setterinherited
displayName → String
no setterinherited
documentation → String?
finalinherited
globalConstantTable → HTGlobalConstantTable
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
idRange → SourceRange
finalinherited
index → int
final
isConst → bool
Wether this declaration is a const value.
no setteroverride
isExternal → bool
Wether this declaration is from outside of the script.
finalinherited
isField → bool
Wether this declaration is a member of a class or struct.
finalinherited
isMutable → bool
Wether this declaration's value can be assigned to another value.
finalinherited
isPrivate → bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic → bool
Wether this declaration is static in a class.
finalinherited
isTopLevel → bool
Wether this declaration is defined on top level of a source.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → HTSource?
finalinherited
sourceRange → SourceRange
finalinherited
type → Type
final
value ↔ dynamic
getter/setter pairinherited-setteroverride-getter

Methods

clone() → HTConstantValue
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited