RedirectingConstructor class

Constructors

RedirectingConstructor(String name, {String? key, List<int> positionalArgsIp = const [], Map<String, int> namedArgsIp = const {}})

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String?
final
name → String
id of super class's constructor
final
namedArgsIp → Map<String, int>
Holds ips of super class's constructor's named argumnets
final
positionalArgsIp → List<int>
Holds ips of super class's constructor's positional argumnets
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited