HTObject mixin

A mixin for store and access symbols from a collection.

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueType HTType?
no setter

Methods

contains(String id) bool
define(String id, dynamic value, {bool override = false}) → void
memberGet(String id, {String? from, bool isRecursive = false, bool ignoreUndefined = false}) → dynamic
Fetch a member by the id, in the form of
memberSet(String id, dynamic value, {String? from, bool defineIfAbsent = false}) → void
Assign a value to a member by the id, in the form of
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subGet(dynamic id, {String? from}) → dynamic
Fetch a member by the id, in the form of
subSet(dynamic id, dynamic value, {String? from}) → void
Assign a value to a member by the id, in the form of
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

nullValue → const _HTNull
An constant null object.