subSet method

void subSet(
  1. dynamic id,
  2. dynamic value, {
  3. String? from,
})

Assign a value to a member by the id, in the form of

object[id] = value

id is of dynamic type, and will be converted to String by toString method.

Implementation

void subSet(dynamic id, dynamic value, {String? from}) {
  memberSet(id.toString(), value, from: from);
}