UnresolvedImport class

Constructors

UnresolvedImport(String fromPath, {String? alias, Set<String> showList = const {}, bool isExported = true})

Properties

alias → String?
final
fromPath → String
final
hashCode → int
The hash code for this object.
no setterinherited
isExported → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showList → Set<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited