HTAnalysisError class
An implementation of HTError that used by HTAnalyzer. The format of the printed error content is different from HTError.
- Implemented types
Constructors
-
HTAnalysisError(HTErrorCode code, HTErrorType type, {required String message, String? extra, List<
String> interpolations = const [], String? correction, required String filename, required int line, required int column, int offset = 0, int length = 0, List<HTDiagnosticMessage> contextMessages = const []}) - HTAnalysisError.assignType(String id, String valueType, String declValue, {String? extra, String? correction, required String filename, required int line, required int column, required int offset, required int length})
- Error: Type check failed.
- HTAnalysisError.constValue(String id, {String? extra, String? correction, required String filename, required int line, required int column, required int offset, required int length})
-
HTAnalysisError.fromError(HTError error, {required String filename, required int line, required int column, int offset = 0, int length = 0, List<
HTDiagnosticMessage> contextMessages = const []}) - HTAnalysisError.importSelf({String? extra, String? correction, required String filename, required int line, required int column, required int offset, required int length})
Properties
- code → HTErrorCode
-
final
- column → int
-
final
-
contextMessages
→ List<
HTDiagnosticMessage> -
final
- correction → String?
-
final
- extra → String?
-
final
- filename → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
final
- line → int
-
final
- message → String
-
no setteroverride
- name → String
-
no setteroverride
- offset → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → MessageSeverity
-
no setteroverride
- type → HTErrorType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited