HTBundler class
Handle import statement in sources and bundle all related sources into a single compilation
Constructors
-
HTBundler({BundlerConfig? config, required HTResourceContext<
HTSource> sourceContext, required HTParser parser})
Properties
- config ↔ BundlerConfig
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- parser → HTParser
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceContext
→ HTResourceContext<
HTSource> -
final
Methods
-
bundle(
{required HTSource source, Version? version}) → ASTCompilation - Parse a string content and generate a library, will import other files.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited