HTBytecodeModule class
A bytecode module contains the compiled bytes, after the execution of the interpreter, it will also contain namespaces & values.
- Inheritance
-
- Object
- HTGlobalConstantTable
- HTBytecodeModule
- Mixed-in types
Constructors
- HTBytecodeModule({required String id, required Uint8List bytes})
Properties
- bytes ↔ Uint8List
-
The bytecode, stores as uint8 list
getter/setter pairinherited
- compiledAt ↔ String?
-
The compiled time of this module, will be read from the bytes later.
getter/setter pair
-
constants
→ Map<
Type, List> -
Const tables stored by its type.
finalinherited
- curByte → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The name of this module.
final
- invoke ↔ String?
-
getter/setter pair
- ip ↔ int
-
Instruction pointer
getter/setter pairinherited
-
jsonSources
→ Map<
String, HTJsonSource> -
An interpreted non-source, such as JSON, is exist as a value in bytecode module.
This is empty until interpreter insert the evaled values.
final
-
namedArgs
↔ Map<
String, dynamic> -
getter/setter pair
-
namespaces
→ Map<
String, HTNamespace> -
An interpreted source is exist as a namespace in bytecode module.
This is empty until interpreter insert the evaled values.
final
- positionalArgs ↔ List
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ int
-
time stamp of the start time of the execution of this module
getter/setter pair
- version ↔ Version?
-
The version of this module, will be read from the bytes later.
getter/setter pair
Methods
-
addGlobalConstant<
T> (T value) → int -
Add a constant value with type T to the table.
inherited
-
getConstString(
) → String - fetch a contant value defined within any namespace of this module.
-
getGlobalConstant(
Type type, int index) → dynamic -
Get a constant value in the table at the
index.inherited -
init(
{String? invoke, List positionalArgs = const [], Map< String, dynamic> namedArgs = const {}}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → int -
Fetch a single byte at the current instruction pointer
inherited
-
readBool(
) → bool -
Fetch a bool value from the bytes list
inherited
-
readFloat64(
) → double -
Fetch a float64 from the bytes list
inherited
-
readInt16(
) → int -
Fetch a int64 from the bytes list
inherited
-
readInt64(
) → int -
Fetch a int32 from the bytes list
Fetch a int64 from the bytes list
Fetch a float64 from the bytes list
Fetch a int64 from the bytes list
Fetch a int64 from the bytes list
inherited
-
readUint16(
) → int -
Fetch a uint16 from the bytes list
inherited
-
readUint32(
) → int -
Fetch a uint32 from the bytes list
inherited
-
readUint8(
) → int -
Fetch a uint8 from the bytes list
inherited
-
readUtf8String(
) → String -
Fetch a utf8 string from the bytes list
inherited
-
skip(
int distance) → void -
Skip forward
distanceof bytesinherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited