jsonSources property
An interpreted non-source, such as JSON, is exist as a value in bytecode module. This is empty until interpreter insert the evaled values.
Implementation
final Map<String, HTJsonSource> jsonSources = {};
An interpreted non-source, such as JSON, is exist as a value in bytecode module. This is empty until interpreter insert the evaled values.
final Map<String, HTJsonSource> jsonSources = {};