GotoInfo mixin
Execution jump point, this is a reletive jump from the current ip of the bytecode module. For absolute jumpo point, will use HTOpCode.anchor and HTOpCode.goto.
- Mixin applications
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited