HTError class

Implementers

Constructors

HTError(HTErrorCode code, HTErrorType type, {required String message, String? extra, List interpolations = const [], String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError can not be created by default constructor.
HTError.abstracted(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Cannot create instance from abstract class.
HTError.abstractFunction(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Cannot call an abstract function.
HTError.argInit({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Only optional or named arguments can have initializer.
HTError.argType(String id, String assignType, String declValue, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Arguments type check failed.
HTError.arity(String id, int argsCount, int paramsCount, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Function arity check failed.
HTError.assertionFailed(String message, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.assignType(String id, String valueType, String declValue, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Type check failed.
HTError.asyncConstructor({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Constructor cannot be async.
HTError.awaitExpression({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal await expression appeared outside of async function.
HTError.awaitWithoutAsync({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Await appeared outside an async function.
HTError.binding({String? filename, int? line, int? column, int? offset, int? length})
Error: Bind a non literal function is not allowed.
HTError.bytecode({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Unrecognizable bytecode.
HTError.bytesSig({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Bytecode signature check failed.
HTError.callNullObject(String symbol, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Visit null object.
HTError.castee(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal castee.
HTError.circleInit(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Variable's initialization relies on itself.
HTError.condition({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: if/while condition expression must be boolean type.
HTError.constInClass({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Const value in class must be also static.
HTError.constMustInit(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Const variable must be initialized.
HTError.defined(String id, HTErrorType type, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: A same name declaration is already existed.
HTError.definedImportSymbol(String id, String from, String exist, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: A same name declaration is already existed.
HTError.delete({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Can only delete a identifier.
HTError.exportNonHetuSource({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.extendsSelf({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Symbol is not a class name.
HTError.extern(String message, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: dart error
HTError.external(String semanticName, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: external type is not allowed.
HTError.externalCtorWithReferCtor({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.externalVar({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Can not declare a external variable in global namespace.
HTError.getterParam({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Getter should have empty parameters list.
HTError.ifBlock({String? filename, int? line, int? column, int? offset, int? length})
Error: if statement's then and else should be both expression or both block
HTError.immutable(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Try to assign a immutable variable.
HTError.importListOnNonHetuSource({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.invalidDeclTypeOfValue({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal value appeared on left of assignment.
HTError.invalidLeftValue({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal value appeared on left of assignment.
HTError.iterable(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Object is not iterable.
HTError.misplacedBreak({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Break appeared outside of a loop.
HTError.misplacedContinue({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Continue appeared outside of a function.
HTError.misplacedReturn({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Return appeared outside of a function.
HTError.misplacedSuper({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: super appeared outside of a inherited class's instance method.
HTError.misplacedThis({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: this appeared outside of a instance method.
HTError.missingFuncBody(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Not a super class of this instance. Error: Try to call a function without definition.
HTError.namedArg(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Named arguments does not exist.
HTError.nestedClass({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: external constructor on a normal class. Error: Nested class within another nested class.
HTError.notAbsoluteError(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Module import error
HTError.notCallable(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Object is not callable.
HTError.notClass(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Symbol is not a class name.
HTError.notInitialized(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Try to use a variable before its initialization.
HTError.notMember(String id, String className, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Symbol is not a class member.
HTError.notNamespace(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Symbol is not a namespace name.
HTError.notNewable(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Can not use new on this.
HTError.notSpreadableObj({String? filename, int? line, int? column, int? offset, int? length})
Error: Bind a non literal function is not allowed.
HTError.notStruct({String? filename, int? line, int? column, int? offset, int? length})
Error: Bind a non literal function is not allowed.
HTError.notSuper(String classId, String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Not a super class of this instance.
HTError.notType(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Symbol is not a type.
HTError.nullableAssign({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Cannot ssign to a nullable value.
HTError.nullSubSetKey({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.outOfRange(int index, int range, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Calling method on null object.
HTError.outsideThis({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: This appeared outside of a function.
HTError.privateMember(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Access private member.
HTError.resourceDoesNotExist(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Resource does not exit.
HTError.returnType(String returnedType, String funcName, String declReturnType, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Return value type check failed.
HTError.scriptThrows(Object message, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.setterArity({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal setter declaration.
HTError.sourceProviderError(String id, String from, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Module import error
HTError.stringInterpolation({String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: String interpolation has to be a single expression.
HTError.structMemberId(String met, {String? filename, int? line, int? column, int? offset, int? length})
Error: Struct member id should be symbol or string.
HTError.subGetKey(dynamic key, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Subget key is not int
HTError.typeCast(String from, String to, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Illegal type cast.
HTError.undefined(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Try to use a undefined variable.
HTError.undefinedExternal(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Try to use a external variable without its binding.
HTError.undefinedMember(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Undefined member of a class/enum.
HTError.undefinedOperator(String id, String op, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Unknown operator.
HTError.unexpected(String whileParsing, String expected, String met, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Expected a token while met another.
HTError.unexpectedEmptyList(String listName, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Type arguments is emtpy brackets.
HTError.unexpectedToken(String expected, String met, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Expected a token while met another.
HTError.uninitialized(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Undefined member of a class/enum.
HTError.unknownExternalTypeName(String id, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Try to operate unkown type object.
HTError.unknownOpCode(int opcode, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Access private member.
HTError.unkownSourceType(String ext, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
HTError.unkownValueType(int valType, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Unknown value type code
HTError.unresolvedNamedStruct(String id, {String? filename, int? line, int? column, int? offset, int? length})
Error: Unevalable source type.
HTError.unsupported(String name, String version, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: unsupported runtime operation
HTError.version(String codeVer, String itpVer, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Incompatible bytecode version.
HTError.visitMemberOfNullObject(String symbol, String method, {String? extra, String? correction, String? filename, int? line, int? column, int? offset, int? length})
Error: Calling method on null object.

Properties

code HTErrorCode
final
column int?
final
correction String?
final
extra String?
final
filename String?
final
hashCode int
The hash code for this object.
no setterinherited
length int?
final
line int?
final
message String
no setter
name String
no setter
offset int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity MessageSeverity
no setter
type HTErrorType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited