instanceMemberSet method
void
instanceMemberSet(})
Assign a value to a instance member of the Dart class by the id, in the form of
object.key = value
Implementation
void instanceMemberSet(dynamic instance, String id, dynamic value,
{bool ignoreUndefined = false}) =>
throw HTError.undefined(id);