HTExternalInstance<T> class

Class for external object.

Mixed-in types

Constructors

HTExternalInstance(T externalObject, HTInterpreter interpreter, String typeString)
Create a external class object.

Properties

externalClass HTExternalClass?
latefinal
externalObject → T
the external object.
final
hashCode int
The hash code for this object.
no setterinherited
interpreter HTInterpreter
latefinalinherited
klass HTClass?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeString String
final
valueType HTType
latefinaloverride-getter

Methods

contains(String id) bool
inherited
define(String id, dynamic value, {bool override = false}) → void
inherited
help() String
memberGet(String id, {String? from, bool isRecursive = false, bool ignoreUndefined = false}) → dynamic
Fetch a member by the id, in the form of
override
memberSet(String id, dynamic value, {String? from, bool defineIfAbsent = false}) → void
Assign a value to a member by the id, in the form of
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subGet(dynamic id, {String? from}) → dynamic
Fetch a member by the id, in the form of
inherited
subSet(dynamic id, dynamic value, {String? from}) → void
Assign a value to a member by the id, in the form of
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited