HTInterpreterLoopInfo class

Constructors

HTInterpreterLoopInfo(int startIp, int continueIp, int breakIp, HTNamespace namespace)

Properties

breakIp int
final
continueIp int
final
hashCode int
The hash code for this object.
no setterinherited
namespace HTNamespace
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited