HTStackFrame class
Properties
anchors
→ List <int >
final
hashCode
→ int
The hash code for this object.
no setter inherited
localSymbol
↔ String ?
getter/setter pair
loops
→ List <HTInterpreterLoopInfo >
Loop point is stored as stack form.
Break statement will jump to the last loop point,
and remove it from this stack.
Return statement will clear loop points by
loopCount in current stack frame.
final
operandStack
→ List
Operand stack — replaces the old localValue + registerValues design.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
top
→ dynamic
no setter
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop ()
→ dynamic
push (dynamic v )
→ void
toString ()
→ String
A string representation of this object.
inherited