HTType class abstract
Type is basically a set of things. It is used to check errors in code.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String?
-
final
- isBottom → bool
-
This type is assignable to all other types.
no setter
- isResolved → bool
-
no setter
- isTop → bool
-
Every type is assignable to a top type,
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isA(
HTType? other) → bool - Check wether value of this HTType can be assigned to other HTType.
-
isNotA(
HTType? other) → bool - Wether object of this HTType cannot be assigned to other HTType
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
HTDeclarationNamespace namespace) → HTType -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override