utils/math library

Extensions

RandomEx on Random

Constants

kDegrees2Radians → const double
Constant factor to convert and angle from degrees to radians.
kRadians2Degrees → const double
Constant factor to convert and angle from radians to degrees.

Functions

aangle(num x1, num y1, num x2, num y2) double
angle(num x1, num y1, num x2, num y2) double
assume p1(x1, y1) is the center, the angle of the line between p1 and p2 rotates from the vertical Y axis line of the coordinates
degrees(double radians) double
Convert radians to degrees.
gaussianNoise(double mean, double standardDeviation, {Random? randomGenerator}) double
gradualValue(num input, num target, {double power = 0.5}) double
Input a value and a target, get a output between 0.0 and 1.0. The more the input is near the target, the more the output is near 1.0.
radians(double degrees) double
Convert degrees to radians.
radiusToSigma(double radius) double