HTExternalEnum class

Inheritance
Mixed-in types

Constructors

HTExternalEnum(HTInterpreter interpreter, {required String id, String? documentation})

Properties

classId String?
Wether this declaration is a class member.
finalinherited
closure HTDeclarationNamespace?
finalinherited
declType HTType?
no setterinherited
displayName String
no setterinherited
documentation String?
finalinherited
externalClass HTExternalClass?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
idRange SourceRange
finalinherited
interpreter HTInterpreter
latefinalinherited
isConst bool
Wether this declaration is a const value.
finalinherited
isExternal bool
Wether this declaration is from outside of the script.
finalinherited
isField bool
Wether this declaration is a member of a class or struct.
finalinherited
isMutable bool
Wether this declaration's value can be assigned to another value.
finalinherited
isNested bool
no setter
isPrivate bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic bool
Wether this declaration is static in a class.
finalinherited
isTopLevel bool
Wether this declaration is defined on top level of a source.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source HTSource?
finalinherited
sourceRange SourceRange
finalinherited
value ↔ dynamic
getter/setter pairinherited
valueType HTType?
no setterinherited

Methods

clone() HTExternalEnum
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
contains(String id) bool
inherited
define(String id, dynamic value, {bool override = false}) → void
inherited
memberGet(String id, {String? from, bool isRecursive = false, bool ignoreUndefined = false}) → dynamic
Fetch a member by the id, in the form of
override
memberSet(String id, dynamic value, {String? from, bool defineIfAbsent = false}) → void
Assign a value to a member by the id, in the form of
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
override
subGet(dynamic id, {String? from}) → dynamic
Fetch a member by the id, in the form of
inherited
subSet(dynamic id, dynamic value, {String? from}) → void
Assign a value to a member by the id, in the form of
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited