HTParameter class
An implementation of HTVariable for function parameter declaration.
- Inheritance
-
- Object
- HTDeclaration
- HTVariableDeclaration
- HTVariable
- HTParameter
- Implemented types
Constructors
- HTParameter({required String id, required HTInterpreter interpreter, String? file, String? module, required HTNamespace closure, HTType? declType, int? ip, int? line, int? column, bool isVariadic = false, bool isOptional = false, bool isNamed = false, bool isInitialization = false})
- Create a standard HTParameter.
Properties
- classId → String?
-
Wether this declaration is a class member.
finalinherited
- closure → HTNamespace
-
no setterinherited
- column ↔ int?
-
latefinalinherited
- declType → HTType?
-
The declared HTType of this symbol, will be used to
compare with the value type before compile to
determine wether an value binding (assignment) is legal.
no setterinherited
- displayName → String
-
no setterinherited
- documentation → String?
-
finalinherited
- externalClass ↔ HTExternalClass?
-
getter/setter pairinherited
- file ↔ String
-
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- idRange → SourceRange
-
finalinherited
- interpreter ↔ HTInterpreter
-
latefinalinherited
- ip ↔ int?
-
latefinalinherited
- isConst → bool
-
Wether this declaration is a const value.
finalinherited
- isExternal → bool
-
Wether this declaration is from outside of the script.
finalinherited
- isField → bool
-
Wether this declaration is a member of a class or struct.
finalinherited
- isInitialization → bool
-
final
- isMutable → bool
-
Wether this declaration's value can be assigned to another value.
finalinherited
- isNamed → bool
-
final
- isOptional → bool
-
final
- isPrivate → bool
-
Wether this declaration is only accessible from the same namespace.
no setterinherited
- isStatic → bool
-
Wether this declaration is static in a class.
finalinherited
- isTopLevel → bool
-
Wether this declaration is defined on top level of a source.
finalinherited
- isVariadic → bool
-
final
- lateFinalize → bool
-
finalinherited
- line ↔ int?
-
latefinalinherited
- module ↔ String
-
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → HTSource?
-
finalinherited
- sourceRange → SourceRange
-
finalinherited
- value ↔ dynamic
-
Assign a new value to this variable.
getter/setter pairinherited
Methods
-
clone(
) → HTParameter -
Create a copy of this declaration,
mainly used on class member inheritance and function arguments passing.
override
-
initialize(
) → void -
Initialize this variable with its declared initializer bytecode
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{bool resolveType = true}) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited