subGet method

dynamic subGet(
  1. dynamic id, {
  2. String? from,
})

Fetch a member by the id, in the form of

object[id]

id is of dynamic type, and will be converted to String by toString method.

Implementation

dynamic subGet(dynamic id, {String? from}) {
  return memberGet(id.toString(), from: from, ignoreUndefined: true);
}