HTNamedStruct class

Unlike class and function, the declaration of a struct is a value and struct object does not extends from this.

Inheritance
Mixed-in types

Constructors

HTNamedStruct({required String id, required HTInterpreter interpreter, required String file, required String module, HTDeclarationNamespace? closure, String? documentation, String? prototypeId, List<String> mixinIds = const [], HTSource? source, bool isPrivate = false, bool isTopLevel = false, int? staticDefinitionIp, int? definitionIp})

Properties

classId String?
Wether this declaration is a class member.
finalinherited
closure HTDeclarationNamespace?
finalinherited
column int?
latefinalinherited
declType HTType?
no setterinherited
displayName String
no setterinherited
documentation String?
finalinherited
file String
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
idRange SourceRange
finalinherited
interpreter HTInterpreter
latefinalinherited
ip int?
latefinalinherited
isConst bool
Wether this declaration is a const value.
finalinherited
isExternal bool
Wether this declaration is from outside of the script.
finalinherited
isField bool
Wether this declaration is a member of a class or struct.
finalinherited
isMutable bool
Wether this declaration's value can be assigned to another value.
finalinherited
isPrivate bool
Wether this declaration is only accessible from the same namespace.
no setterinherited
isStatic bool
Wether this declaration is static in a class.
finalinherited
isTopLevel bool
Wether this declaration is defined on top level of a source.
finalinherited
line int?
latefinalinherited
mixinIds List<String>
final
module String
latefinalinherited
prototypeId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source HTSource?
finalinherited
sourceRange SourceRange
finalinherited
staticDefinitionIp int?
final
value HTStruct
getter/setter pairinherited-setteroverride-getter

Methods

clone() HTNamedStruct
Create a copy of this declaration, mainly used on class member inheritance and function arguments passing.
override
createObject({List positionalArgs = const [], Map<String, dynamic> namedArgs = const {}}) HTStruct
initialize() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited