subGet method
Fetch a member by the id, in the form of
object[id]
id is of dynamic type, and will be converted to String by toString method.
Implementation
@override
dynamic subGet(dynamic id, {String? from}) => memberGet(id, from: from);
Fetch a member by the id, in the form of
object[id]
id is of dynamic type, and will be converted to String by toString method.
@override
dynamic subGet(dynamic id, {String? from}) => memberGet(id, from: from);